@@ -13,7 +13,8 @@ std::vector<double> do_focal_sum(std::vector<double> d, Rcpp::NumericMatrix w, s
 	std::vector<double> val(n);
 	
 	if ((wrows % 2 == 0) | (wcols % 2 == 0)){
-		Rcpp::Rcerr << "weights matrix must have uneven sides";
+		Rcpp::Rcerr << wrows << " " << wcols << "\n";		
+		Rcpp::Rcerr << "weights matrix must have uneven sides\n";
 		return(val);
 	}
 
@@ -45,12 +46,14 @@ std::vector<double> do_focal_sum(std::vector<double> d, Rcpp::NumericMatrix w, s
 						size_t p = 0;
 						for (int j = -wr; j <= wr; j++) {
 							for (int k = -wc; k <= wc; k++) {
-								double a = d[j * ncol + k + i];
-								if ( !std::isnan(a) ) {
-									val[i] += a * w[q];
-									p++;
+								if (!std::isnan(w[q])) {
+									double a = d[j * ncol + k + i];
+									if ( !std::isnan(a) ) {
+										val[i] += a * w[q];
+										p++;
+									}
+									q++;
 								}
-								q++;
 							}
 						}
 						if (p==0) {
@@ -84,10 +87,12 @@ std::vector<double> do_focal_sum(std::vector<double> d, Rcpp::NumericMatrix w, s
 					val[i] = 0;
 					for (int j = -wr; j <= wr; j++) {
 						for (int k = -wc; k <= wc; k++) {
-							double a = d[j * ncol + k + i];
-							if ( !std::isnan(a) ) {
-								val[i] += a * w[q];
-								p++;
+							if (!std::isnan(w[q])) {				
+								double a = d[j * ncol + k + i];
+								if ( !std::isnan(a) ) {
+									val[i] += a * w[q];
+									p++;
+								}
 							}
 							q++;
 						}
@@ -106,36 +111,91 @@ std::vector<double> do_focal_sum(std::vector<double> d, Rcpp::NumericMatrix w, s
 			}
 		}
 	} else {
+		if (naonly) {
 
-		// first rows
-		for (int i = 0; i < ncol*wr; i++) {  
-			val[i] = NAN;
-		}
-		for (int i = ncol*wr; i < ncol * (nrow-wr); i++) {
-			col = i % ncol;
-			if ((col < wc) | (col > nwc)) {
-				val[i] = NAN;
-			} else {
-				val[i] = 0;
-				size_t q = 0;
-				for (int j = -wr; j <= wr; j++) {
-					for (int k = -wc; k <= wc; k++) {
-						val[i] += d[j * ncol + k + i]  * w[q];
-						q++;
+			// first rows
+			for (int i = 0; i < ncol*wr; i++) {  
+				val[i] = d[i];
+			}
+			
+			for (int i = ncol*wr; i < ncol * (nrow-wr); i++) {
+				bool disnan = std::isnan(d[i]);
+				if (!disnan) {
+					val[i] = d[i];
+				} else {
+
+					col = i % ncol;
+					if ((col < wc) | (col > nwc)) {
+						val[i] = NAN;
+					} else {
+						val[i] = 0;
+						size_t q = 0;
+						if (disnan) {
+							for (int j = -wr; j <= wr; j++) {
+								bool jnot0 = j != 0;
+								for (int k = -wc; k <= wc; k++) {
+									if (!std::isnan(w[q])) {	
+										if (jnot0 && (k != 0)) {
+											val[i] += d[j * ncol + k + i]  * w[q];
+										}
+										q++;
+									}
+								}
+							}
+						} else {
+							for (int j = -wr; j <= wr; j++) {
+								for (int k = -wc; k <= wc; k++) {
+									if (!std::isnan(w[q])) {
+										val[i] += d[j * ncol + k + i]  * w[q];
+									}
+									q++;
+								}
+							}
+						}
+						if (bemean) {
+							val[i] = val[i] / q;
+						}			
 					}
 				}
-				
-				if (bemean) {
-					val[i] = val[i] / q;
-				}			
+				// last rows
+				for (int i = ncol * (nrow-wr); i < n; i++) {  
+					val[i] = d[i];
+				}		
 			}
+			
+		} else {
+
+			// first rows
+			for (int i = 0; i < ncol*wr; i++) {  
+				val[i] = NAN;
+			}
+			for (int i = ncol*wr; i < ncol * (nrow-wr); i++) {
+				col = i % ncol;
+				if ((col < wc) | (col > nwc)) {
+					val[i] = NAN;
+				} else {
+					val[i] = 0;
+					size_t q = 0;
+					for (int j = -wr; j <= wr; j++) {
+						for (int k = -wc; k <= wc; k++) {
+							if (!std::isnan(w[q])) {				
+								val[i] += d[j * ncol + k + i]  * w[q];
+							}
+							q++;
+						}
+					}
+					
+					if (bemean) {
+						val[i] = val[i] / q;
+					}			
+				}
+			}
+			// last rows
+			for (int i = ncol * (nrow-wr); i < n; i++) {  
+				val[i] = NAN;
+			}		
 		}
-		// last rows
-		for (int i = ncol * (nrow-wr); i < n; i++) {  
-			val[i] = NAN;
-		}		
 	}
-	
 	return(val);
 }
 
